@@ -22,7 +22,7 @@ def is_retryable_403(response):
     https://developers.google.com/analytics/devguides/reporting/metadata/v3/errors
     """
     retryable_errors = {"userRateLimitExceeded", "rateLimitExceeded", "quotaExceeded"}
-    error_reasons = {error.get('reason') for error in response.json().get('errors',[])}
+    error_reasons = {error.get('reason') for error in response.json().get('error', {}).get('errors',[])}
 
     if any(error_reasons.intersection(retryable_errors)):
         return True
@@ -41,16 +41,19 @@ def should_giveup(e):
         # All of our retryable errors require a JSON response body
         return False
 
-    should_retry = response.status_code == 429 or is_retryable_403(response)
+    do_retry = should_retry(response)
 
-    if should_retry:
+    if do_retry:
         error_message = response.json().get("error", {}).get("message")
         if error_message:
             LOGGER.info("Encountered retryable %s, backing off exponentially. Details: %s",
                         response.status_code,
                         error_message)
 
-    return not should_retry
+    return not do_retry
+
+def should_retry(response):
+    return response.status_code == 429 or is_retryable_403(response)
 
 def _is_json(response):
     try:
@@ -158,8 +161,8 @@ class Client():
             response = self.session.request(method, url, headers=headers, params=params)
 
         error_message = _is_json(response) and response.json().get("error", {}).get("message")
-        if response.status_code == 400 and error_message:
-            raise Exception("400 Client Error: Bad Request, details: {}".format(error_message))
+        if 400 <= response.status_code < 500 and error_message and not should_retry(response):
+            raise Exception("{} Client Error, error message: {}".format(response.status_code, error_message))
 
         response.raise_for_status()
 
